@@ -41,8 +41,6 @@ K_PLUGIN_FACTORY_WITH_JSON(KateCTagsPluginFactory, "katectagsplugin.json", regis
 KateCTagsPlugin::KateCTagsPlugin(QObject *parent, const QVariantList &)
     : KTextEditor::Plugin(parent)
 {
-    // FIXME KF5
-    // KGlobal::locale()->insertCatalog("kate-ctags-plugin");
 }
 
 /******************************************************************/
@@ -186,7 +184,7 @@ void KateCTagsConfigPage::delGlobalTagTarget()
 }
 
 /******************************************************************/
-bool KateCTagsConfigPage::listContains(const QString &target)
+bool KateCTagsConfigPage::listContains(const QString &target) const
 {
     for (int i = 0; i < m_confUi.targetList->count(); i++) {
         if (m_confUi.targetList->item(i)->text() == target) {
