@@ -133,7 +133,7 @@ static const rapidjson::Value &GetJsonArrayForKey(const rapidjson::Value &v, std
     return dummy;
 }
 
-static QJsonValue encodeUrl(const QUrl url)
+static QJsonValue encodeUrl(const QUrl &url)
 {
     return QJsonValue(QLatin1String(url.toEncoded()));
 }
@@ -302,7 +302,7 @@ static QJsonObject codeActionParams(const QUrl &document, const LSPRange &range,
         diags.push_back(to_json(diagnostic));
     }
     context[QLatin1String(MEMBER_DIAGNOSTICS)] = diags;
-    if (kinds.length()) {
+    if (!kinds.empty()) {
         context[QStringLiteral("only")] = QJsonArray::fromStringList(kinds);
     }
     params[QStringLiteral("context")] = context;
@@ -728,7 +728,7 @@ static std::list<LSPSymbolInformation> parseDocumentSymbols(const rapidjson::Val
         auto list = parent ? &parent->children : &ret;
         if (isPositionValid(range.start()) && isPositionValid(range.end())) {
             QString name = GetStringValue(symbol, "name");
-            LSPSymbolKind kind = (LSPSymbolKind)GetIntValue(symbol, MEMBER_KIND);
+            auto kind = (LSPSymbolKind)GetIntValue(symbol, MEMBER_KIND);
             QString detail = GetStringValue(symbol, MEMBER_DETAIL);
 
             list->push_back({name, kind, range, detail});
@@ -1179,7 +1179,7 @@ static LSPShowMessageParams parseMessage(const rapidjson::Value &result)
     return ret;
 }
 
-void from_json(LSPWorkDoneProgressValue &value, const rapidjson::Value &json)
+static void from_json(LSPWorkDoneProgressValue &value, const rapidjson::Value &json)
 {
     if (!json.IsObject()) {
         return;
@@ -1323,7 +1323,7 @@ public:
         , m_root(root)
         , m_langId(langId)
         , m_init(init)
-        , m_config(config)
+        , m_config(std::move(config))
     {
         // setup async reading
         QObject::connect(&m_sproc, &QProcess::readyReadStandardOutput, utils::mem_fun(&self_type::readStandardOutput, this));
@@ -1875,14 +1875,17 @@ public:
         return send(init_request(QStringLiteral("textDocument/rename"), params), h);
     }
 
-    RequestHandle
-    documentCodeAction(const QUrl &document, const LSPRange &range, const QList<QString> &kinds, QList<LSPDiagnostic> diagnostics, const GenericReplyHandler &h)
+    RequestHandle documentCodeAction(const QUrl &document,
+                                     const LSPRange &range,
+                                     const QList<QString> &kinds,
+                                     const QList<LSPDiagnostic> &diagnostics,
+                                     const GenericReplyHandler &h)
     {
         auto params = codeActionParams(document, range, kinds, diagnostics);
         return send(init_request(QStringLiteral("textDocument/codeAction"), params), h);
     }
 
-    RequestHandle documentSemanticTokensFull(const QUrl &document, bool delta, const QString requestId, const LSPRange &range, const GenericReplyHandler &h)
+    RequestHandle documentSemanticTokensFull(const QUrl &document, bool delta, const QString &requestId, const LSPRange &range, const GenericReplyHandler &h)
     {
         auto params = textDocumentParams(document);
         // Delta
@@ -2104,7 +2107,7 @@ make_handler(const ReplyHandler<ReplyType> &h, const QObject *context, typename
 }
 
 LSPClientServer::LSPClientServer(const QStringList &server, const QUrl &root, const QString &langId, const QJsonValue &init, ExtraServerConfig config)
-    : d(new LSPClientServerPrivate(this, server, root, langId, init, config))
+    : d(new LSPClientServerPrivate(this, server, root, langId, init, std::move(config)))
 {
 }
 
@@ -2145,7 +2148,7 @@ bool LSPClientServer::start(bool forwardStdError)
 
 void LSPClientServer::stop(int to_t, int to_k)
 {
-    return d->stop(to_t, to_k);
+    d->stop(to_t, to_k);
 }
 
 int LSPClientServer::cancel(int reqid)
@@ -2292,14 +2295,14 @@ LSPClientServer::RequestHandle LSPClientServer::documentCodeAction(const QUrl &d
 }
 
 LSPClientServer::RequestHandle
-LSPClientServer::documentSemanticTokensFull(const QUrl &document, const QString requestId, const QObject *context, const SemanticTokensDeltaReplyHandler &h)
+LSPClientServer::documentSemanticTokensFull(const QUrl &document, const QString &requestId, const QObject *context, const SemanticTokensDeltaReplyHandler &h)
 {
     auto invalidRange = KTextEditor::Range::invalid();
     return d->documentSemanticTokensFull(document, /* delta = */ false, requestId, invalidRange, make_handler(h, context, parseSemanticTokensDelta));
 }
 
 LSPClientServer::RequestHandle LSPClientServer::documentSemanticTokensFullDelta(const QUrl &document,
-                                                                                const QString requestId,
+                                                                                const QString &requestId,
                                                                                 const QObject *context,
                                                                                 const SemanticTokensDeltaReplyHandler &h)
 {
@@ -2321,42 +2324,42 @@ LSPClientServer::documentInlayHint(const QUrl &document, const LSPRange &range,
 
 void LSPClientServer::executeCommand(const LSPCommand &command)
 {
-    return d->executeCommand(command);
+    d->executeCommand(command);
 }
 
 void LSPClientServer::didOpen(const QUrl &document, int version, const QString &langId, const QString &text)
 {
-    return d->didOpen(document, version, langId, text);
+    d->didOpen(document, version, langId, text);
 }
 
 void LSPClientServer::didChange(const QUrl &document, int version, const QString &text, const QList<LSPTextDocumentContentChangeEvent> &changes)
 {
-    return d->didChange(document, version, text, changes);
+    d->didChange(document, version, text, changes);
 }
 
 void LSPClientServer::didSave(const QUrl &document, const QString &text)
 {
-    return d->didSave(document, text);
+    d->didSave(document, text);
 }
 
 void LSPClientServer::didClose(const QUrl &document)
 {
-    return d->didClose(document);
+    d->didClose(document);
 }
 
 void LSPClientServer::didChangeConfiguration(const QJsonValue &settings)
 {
-    return d->didChangeConfiguration(settings);
+    d->didChangeConfiguration(settings);
 }
 
 void LSPClientServer::didChangeWorkspaceFolders(const QList<LSPWorkspaceFolder> &added, const QList<LSPWorkspaceFolder> &removed)
 {
-    return d->didChangeWorkspaceFolders(added, removed);
+    d->didChangeWorkspaceFolders(added, removed);
 }
 
 void LSPClientServer::workspaceSymbol(const QString &symbol, const QObject *context, const WorkspaceSymbolsReplyHandler &h)
 {
-    return d->workspaceSymbol(symbol, make_handler(h, context, parseWorkspaceSymbols));
+    d->workspaceSymbol(symbol, make_handler(h, context, parseWorkspaceSymbols));
 }
 
 #include "moc_lspclientserver.cpp"
