@@ -29,6 +29,7 @@
 #include "kateupdatedisabler.h"
 #include "kateviewspace.h"
 #include "ktexteditor_utils.h"
+#include "mainwindow_commands.h"
 #include "texthint/KateTextHintManager.h"
 
 #include <KActionCollection>
@@ -114,6 +115,7 @@ QSize KateContainerStackedLayout::minimumSize() const
 KateMainWindow::KateMainWindow(KConfig *sconfig, const QString &sgroup, bool userTriggered)
     : KateMDI::MainWindow(nullptr)
     , m_wrapper(new KTextEditor::MainWindow(this))
+    , m_mainWindowCommands(this)
 {
     /**
      * we don't want any flicker here
@@ -192,6 +194,9 @@ KateMainWindow::KateMainWindow(KConfig *sconfig, const QString &sgroup, bool use
 
     // trigger proper focus restore
     m_viewManager->triggerActiveViewFocus();
+
+    // log the path
+    Utils::showMessage(qEnvironmentVariable("PATH"), QIcon(), i18n("PATH"), MessageType::Info, m_wrapper);
 }
 
 KateMainWindow::~KateMainWindow()
@@ -219,11 +224,10 @@ KateMainWindow::~KateMainWindow()
         KateApp::self()->documentManager()->closeDocuments(docs, false);
     }
 
-    // Delete diagnostics view earlier so that destruction is faster
-    // If we delay it then each provider will get unregisted one by one
-    // and slow down the destruction as we will be clearing diagnostics
-    // for each provider individually
-    delete m_diagView;
+    // ensure we don't do too much work during destruction
+    if (m_diagView) {
+        m_diagView->shutdownStarts();
+    }
 
     // unregister mainwindow in app
     KateApp::self()->removeMainWindow(this);
@@ -235,7 +239,10 @@ KateMainWindow::~KateMainWindow()
     delete m_viewManager;
     m_viewManager = nullptr;
 
-    // kill the wrapper object, now that all views are dead
+    // delete diagnostics late, plugins and Co. need to be removed first, bug 499119
+    delete m_diagView;
+
+    // kill the wrapper object, now that all plugins/views are dead
     delete m_wrapper;
     m_wrapper = nullptr;
 }
@@ -280,25 +287,29 @@ void KateMainWindow::setupImportantActions()
 #endif
 
     // Load themes
-    KColorSchemeManager *manager = new KColorSchemeManager(this);
-    auto *colorSelectionMenu = KColorSchemeMenu::createMenu(manager, this);
+#if KCOLORSCHEME_VERSION < QT_VERSION_CHECK(6, 6, 0)
+    auto manager = new KColorSchemeManager(this);
+#else
+    auto manager = KColorSchemeManager::instance();
+#endif
+    KActionMenu *colorSelectionMenu = KColorSchemeMenu::createMenu(manager, this);
     colorSelectionMenu->menu()->setTitle(i18n("&Window Color Scheme"));
     ac->addAction(QStringLiteral("colorscheme_menu"), colorSelectionMenu);
 
     QAction *a = ac->addAction(KStandardAction::Back, QStringLiteral("view_prev_tab"));
     a->setText(i18n("&Previous Tab"));
     a->setWhatsThis(i18n("Focus the previous tab."));
-    auto prev = KStandardShortcut::tabPrev();
+    QList<QKeySequence> prev = KStandardShortcut::tabPrev();
     prev.removeAll(Qt::CTRL | Qt::Key_BracketLeft);
-    actionCollection()->setDefaultShortcuts(a, a->shortcuts() << prev);
+    KActionCollection::setDefaultShortcuts(a, a->shortcuts() << prev);
     connect(a, &QAction::triggered, this, &KateMainWindow::slotFocusPrevTab);
 
     a = ac->addAction(KStandardAction::Forward, QStringLiteral("view_next_tab"));
     a->setText(i18n("&Next Tab"));
     a->setWhatsThis(i18n("Focus the next tab."));
-    auto next = KStandardShortcut::tabNext();
+    QList<QKeySequence> next = KStandardShortcut::tabNext();
     next.removeAll(Qt::CTRL | Qt::Key_BracketRight);
-    actionCollection()->setDefaultShortcuts(a, a->shortcuts() << next);
+    KActionCollection::setDefaultShortcuts(a, a->shortcuts() << next);
     connect(a, &QAction::triggered, this, &KateMainWindow::slotFocusNextTab);
 
     constexpr int switchToTabCount = 10;
@@ -314,9 +325,9 @@ void KateMainWindow::setupImportantActions()
         // NOTE default shortucts added for non-macOS platforms only, due to macOS input complexities.
         // Only add default shortcut bindings for the first 10 tabs, regardless of switchToTabCount.
         if (i < shortcutToKey0) {
-            ac->setDefaultShortcut(action, QStringLiteral("Alt+%1").arg(i));
+            KActionCollection::setDefaultShortcut(action, QStringLiteral("Alt+%1").arg(i));
         } else if (i == shortcutToKey0) {
-            ac->setDefaultShortcut(action, QKeySequence(Qt::ALT | Qt::Key_0));
+            KActionCollection::setDefaultShortcut(action, QKeySequence(Qt::ALT | Qt::Key_0));
         }
 #endif
     }
@@ -325,7 +336,7 @@ void KateMainWindow::setupImportantActions()
     a = ac->addAction(QStringLiteral("view_quick_open"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("quickopen")));
     a->setText(i18n("&Quick Open"));
-    ac->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_O));
+    KActionCollection::setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_O));
     connect(a, &QAction::triggered, this, &KateMainWindow::slotQuickOpen);
     a->setWhatsThis(i18n("Open a form to quick open documents."));
 
@@ -381,7 +392,7 @@ void KateMainWindow::setupActions()
     m_fileOpenRecent = KStandardAction::openRecent(
         m_viewManager,
         [this](const QUrl &url) {
-            viewManager()->openUrlOrProject(url);
+            viewManager()->openRecent(url);
         },
         this);
     m_fileOpenRecent->setMaxItems(KateConfigDialog::recentFilesMaxCount());
@@ -391,7 +402,7 @@ void KateMainWindow::setupActions()
     a = ac->addAction(QStringLiteral("file_save_all"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("document-save-all")));
     a->setText(i18n("Sa&ve All"));
-    ac->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::Key_L));
+    KActionCollection::setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::Key_L));
     connect(a, &QAction::triggered, KateApp::self()->documentManager(), &KateDocManager::saveAll);
     a->setWhatsThis(i18n("Save all open, modified documents to disk."));
 
@@ -404,7 +415,7 @@ void KateMainWindow::setupActions()
     a->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy-path")));
     a->setText(i18n("Copy Location"));
     connect(a, &QAction::triggered, KateApp::self()->documentManager(), [this]() {
-        auto &&view = viewManager()->activeView();
+        KTextEditor::View *view = viewManager()->activeView();
         KateFileActions::copyFilePathToClipboard(view->document());
     });
     a->setWhatsThis(i18n("Copies the file path of the current file to clipboard."));
@@ -413,7 +424,7 @@ void KateMainWindow::setupActions()
     a->setIcon(QIcon::fromTheme(QStringLiteral("document-open-folder")));
     a->setText(i18n("&Open Containing Folder"));
     connect(a, &QAction::triggered, KateApp::self()->documentManager(), [this]() {
-        auto &&view = viewManager()->activeView();
+        KTextEditor::View *view = viewManager()->activeView();
         KateFileActions::openContainingFolder(view->document());
     });
     a->setWhatsThis(i18n("Copies the file path of the current file to clipboard."));
@@ -422,7 +433,7 @@ void KateMainWindow::setupActions()
     a->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
     a->setText(i18nc("@action:inmenu", "Rename..."));
     connect(a, &QAction::triggered, KateApp::self()->documentManager(), [this]() {
-        auto &&view = viewManager()->activeView();
+        KTextEditor::View *view = viewManager()->activeView();
         KateFileActions::renameDocumentFile(this, view->document());
     });
     a->setWhatsThis(i18n("Renames the file belonging to the current document."));
@@ -431,7 +442,7 @@ void KateMainWindow::setupActions()
     a->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     a->setText(i18nc("@action:inmenu", "Delete"));
     connect(a, &QAction::triggered, KateApp::self()->documentManager(), [this]() {
-        auto &&view = viewManager()->activeView();
+        KTextEditor::View *view = viewManager()->activeView();
         KateFileActions::deleteDocumentFile(this, view->document());
     });
     a->setWhatsThis(i18n("Deletes the file belonging to the current document."));
@@ -440,7 +451,7 @@ void KateMainWindow::setupActions()
     a->setIcon(QIcon::fromTheme(QStringLiteral("dialog-object-properties")));
     a->setText(i18n("Properties"));
     connect(a, &QAction::triggered, KateApp::self()->documentManager(), [this]() {
-        auto &&view = viewManager()->activeView();
+        KTextEditor::View *view = viewManager()->activeView();
         KateFileActions::openFilePropertiesDialog(this, view->document());
     });
     a->setWhatsThis(i18n("Deletes the file belonging to the current document."));
@@ -478,21 +489,28 @@ void KateMainWindow::setupActions()
     connect(a, &QAction::triggered, m_viewManager, &KateViewManager::slotRestoreLastClosedDocument);
     a->setWhatsThis(i18n("Reopen the document or documents that were most recently closed"));
 
+    a = ac->addAction(QStringLiteral("file_close_window"));
+    a->setText(i18n("Close &Window"));
+    KActionCollection::setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_W));
+    // Qt::QueuedConnection: delay real shutdown, as we are inside menu action handling (bug #185708)
+    connect(a, &QAction::triggered, this, &KateMainWindow::close, Qt::QueuedConnection);
+    a->setWhatsThis(i18n("Close this window"));
+
     a = ac->addAction(KStandardAction::Quit, QStringLiteral("file_quit"));
     // Qt::QueuedConnection: delay real shutdown, as we are inside menu action handling (bug #185708)
     connect(a, &QAction::triggered, this, &KateMainWindow::slotFileQuit, Qt::QueuedConnection);
-    a->setWhatsThis(i18n("Close this window"));
+    a->setWhatsThis(i18n("Quit the application"));
 
     a = ac->addAction(QStringLiteral("view_new_view"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("window-new")));
     a->setText(i18n("New &Window"));
-    ac->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_N));
+    KActionCollection::setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_N));
     connect(a, &QAction::triggered, this, &KateMainWindow::newWindow);
     a->setWhatsThis(i18n("Create a new window."));
 
     m_showFullScreenAction = KStandardAction::fullScreen(nullptr, nullptr, this, this);
     ac->addAction(m_showFullScreenAction->objectName(), m_showFullScreenAction);
-    ac->setDefaultShortcut(m_showFullScreenAction, Qt::Key_F11);
+    KActionCollection::setDefaultShortcut(m_showFullScreenAction, Qt::Key_F11);
     connect(m_showFullScreenAction, &QAction::toggled, this, &KateMainWindow::slotFullScreen);
 
     documentOpenWith = new KActionMenu(i18n("Open W&ith"), this);
@@ -513,7 +531,7 @@ void KateMainWindow::setupActions()
     QAction *settingsConfigure = KStandardAction::preferences(this, &KateMainWindow::slotConfigure, ac);
     settingsConfigure->setWhatsThis(i18n("Configure various aspects of this application and the editing component."));
 
-    if (KateApp::self()->pluginManager()->pluginList().size() > 0) {
+    if (!KateApp::self()->pluginManager()->pluginList().empty()) {
         a = ac->addAction(QStringLiteral("help_plugins_contents"));
         a->setText(i18n("&Plugins Handbook"));
         connect(a, &QAction::triggered, this, &KateMainWindow::pluginHelp);
@@ -533,7 +551,7 @@ void KateMainWindow::setupActions()
 
     // session actions, not for KWrite, create the full menu to be able to properly hide it
     if (KateApp::isKate()) {
-        auto sessionsMenu = ac->addAction(QStringLiteral("sessions"));
+        QAction *sessionsMenu = ac->addAction(QStringLiteral("sessions"));
         sessionsMenu->setText(i18n("Sess&ions"));
         sessionsMenu->setMenu(new QMenu(this));
 
@@ -580,7 +598,7 @@ void KateMainWindow::setupActions()
     a = ac->addAction(QStringLiteral("view_history_back"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("arrow-left")));
     a->setText(i18n("Go to Previous Location"));
-    ac->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::Key_1));
+    KActionCollection::setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::Key_1));
     connect(a, &QAction::triggered, this, [this] {
         m_viewManager->activeViewSpace()->goBack();
     });
@@ -589,7 +607,7 @@ void KateMainWindow::setupActions()
     a = ac->addAction(QStringLiteral("view_history_forward"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("arrow-right")));
     a->setText(i18n("Go to Next Location"));
-    ac->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_1));
+    KActionCollection::setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_1));
     connect(a, &QAction::triggered, this, [this] {
         m_viewManager->activeViewSpace()->goForward();
     });
@@ -599,7 +617,7 @@ void KateMainWindow::setupActions()
     a->setText(i18n("Show File Git History"));
     connect(a, &QAction::triggered, this, [this] {
         if (activeView()) {
-            auto url = activeView()->document()->url();
+            QUrl url = activeView()->document()->url();
             if (url.isValid() && url.isLocalFile()) {
                 FileHistory::showFileHistory(url.toLocalFile(), m_wrapper);
             }
@@ -665,7 +683,7 @@ void KateMainWindow::slotDocumentCloseSelected(const QList<KTextEditor::Document
 
 void KateMainWindow::slotDocumentCloseOther()
 {
-    if (auto v = m_viewManager->activeView()) {
+    if (KTextEditor::View *v = m_viewManager->activeView()) {
         slotDocumentCloseOther(v->document());
     }
 }
@@ -767,7 +785,7 @@ KateMainWindow *KateMainWindow::newWindow() const
 {
     // create new window with current session
     // derive size from current one
-    auto win = KateApp::self()->newMainWindow(KateApp::self()->sessionManager()->activeSession()->config(), {}, true);
+    KateMainWindow *win = KateApp::newMainWindow(KateApp::self()->sessionManager()->activeSession()->config(), {}, true);
     win->resize(size());
     return win;
 }
@@ -787,7 +805,7 @@ void KateMainWindow::reloadXmlGui()
 {
     for (KTextEditor::Document *doc : KateApp::self()->documentManager()->documentList()) {
         doc->reloadXML();
-        const auto views = doc->views();
+        const QList<KTextEditor::View *> views = doc->views();
         for (KTextEditor::View *view : views) {
             view->reloadXML();
         }
@@ -826,7 +844,7 @@ void KateMainWindow::readOptions()
     m_paShowTabBar->setChecked(generalGroup.readEntry("Show Tab Bar", true));
     m_paShowUrlNavBar->setChecked(generalGroup.readEntry("Show Url Nav Bar", KateApp::isKate()));
 
-    for (auto a : {m_paShowTabBar, m_paShowPath, m_paShowUrlNavBar, m_paShowStatusBar}) {
+    for (KToggleAction *a : {m_paShowTabBar, m_paShowPath, m_paShowUrlNavBar, m_paShowStatusBar}) {
         connect(a, &QAction::toggled, this, &KateMainWindow::saveOptions);
     }
 
@@ -894,7 +912,7 @@ void KateMainWindow::ensureHamburgerBarSize()
 {
     // Ensure the hamburger menu never gets pushed into the toolbar overflow
     // by setting a minimum size on the bar based on the button's size.
-    if (auto *hamburgerBar = toolBar(QStringLiteral("hamburgerBar"))) {
+    if (KToolBar *hamburgerBar = toolBar(QStringLiteral("hamburgerBar"))) {
         auto *hamburgerMenu = actionCollection()->action(QStringLiteral("hamburger_menu"));
         if (auto *hamburgerButton = hamburgerBar->widgetForAction(hamburgerMenu)) {
             int neededButtonWidth = hamburgerButton->minimumSizeHint().width();
@@ -1038,10 +1056,10 @@ void KateMainWindow::slotDropEvent(QDropEvent *event)
 
         // Try to get the KTextEditor::View that sent this, and activate it, so that the file opens in the
         // view where it was dropped
-        KTextEditor::View *kVsender = qobject_cast<KTextEditor::View *>(QObject::sender());
+        auto *kVsender = qobject_cast<KTextEditor::View *>(QObject::sender());
         if (kVsender != nullptr) {
             if (auto parent = kVsender->parent()) {
-                KateViewSpace *vs = qobject_cast<KateViewSpace *>(parent->parent());
+                auto *vs = qobject_cast<KateViewSpace *>(parent->parent());
                 if (vs != nullptr) {
                     m_viewManager->setActiveSpace(vs);
                 }
@@ -1177,7 +1195,7 @@ void KateMainWindow::slotFullScreen(bool t)
     KToggleFullScreenAction::setFullScreen(this, t);
     QMenuBar *mb = menuBar();
     if (t) {
-        QToolButton *b = new QToolButton(mb);
+        auto *b = new QToolButton(mb);
         b->setDefaultAction(m_showFullScreenAction);
         b->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Ignored));
         b->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
@@ -1450,7 +1468,7 @@ void KateMainWindow::queueModifiedOnDisc(KTextEditor::Document *doc)
 bool KateMainWindow::event(QEvent *e)
 {
     if (e->type() == QEvent::ShortcutOverride) {
-        QKeyEvent *k = static_cast<QKeyEvent *>(e);
+        auto *k = static_cast<QKeyEvent *>(e);
         Q_EMIT unhandledShortcutOverride(k);
 
         if (KateApp::isKate() && k->key() == Qt::Key_Escape && k->modifiers() == Qt::NoModifier) {
@@ -1593,7 +1611,7 @@ void KateMainWindow::slotQuickOpen()
     /**
      * show quick open and pass focus to it
      */
-    KateQuickOpen *quickOpen = new KateQuickOpen(this);
+    auto *quickOpen = new KateQuickOpen(this);
     centralWidget()->setFocusProxy(quickOpen);
     quickOpen->raise();
     quickOpen->show();
